lcvtoolbox.vision.encoding.image.encode\_image\_adaptive
========================================================

.. currentmodule:: lcvtoolbox.vision.encoding.image

.. autofunction:: encode_image_adaptive